/* eslint-disable */
// The eslint rules need to be cleaned up in another task, so we'll just disable them for now.
import React, { ElementType, forwardRef, FunctionComponent, Ref } from "react";
import classNames from "classnames";

export interface GridContainerProps {
    /** Child elements. */
    children?: any;
    /** CSS class names. */
    className?: string;
    /** Ref to the component. */
    ref?: Ref<HTMLElement>;
    /** Customize the tag element (defaults to 'div'). */
    tag?: ElementType;
}

export const GridContainer: FunctionComponent<GridContainerProps> = forwardRef(
    ({
        children,
        className,
        // @ts-ignore Layout is an internal prop to avoid code duplication for LayoutGrid
        layout, 
        tag: Tag = "div",
        ...props
    }, ref: Ref<HTMLElement>) => {
        const layoutClass = layout ? "-layout" : "";
        return (
            <Tag className={classNames(`axiom${layoutClass}-grid-container`, className)} ref={ref} {...props}>
                {children}
            </Tag>
        );
});

export interface GridProps {
    /** Child elements. */
    children?: any;
    /** CSS class names. */
    className?: string;
    /** Ref to the component. */
    ref?: Ref<HTMLElement>;
    /** Customize the tag element (defaults to 'div'). */
    tag?: ElementType;
}

export const Grid: FunctionComponent<GridProps> = forwardRef(
    ({
        children,
        className,
        // @ts-ignore Layout is an internal prop to avoid code duplication for LayoutGrid
        layout,
        tag: Tag = "div",
        ...props
    }, ref: Ref<HTMLElement>) => {
        const layoutClass = layout ? "-layout" : "";
        return (
            <Tag className={classNames(`axiom${layoutClass}-grid`, className)} ref={ref} {...props}>
                {children}
            </Tag>
        );
});

export interface GridCellProps {
    /** Child elements. */
    children?: any;
    /** CSS class names. */
    className?: string;
    /** Number of columns the cell spans on a large screen. */
    large?: number;
    /** Number of columns the cell spans on a medium screen. */
    medium?: number;
    /** Ref to the component. */
    ref?: Ref<HTMLElement>;
    /** Number of columns the cell spans on a small screen. */
    small?: number;
    /** Customize the tag element (defaults to 'div'). */
    tag?: ElementType;
};

export const GridCell: FunctionComponent<GridCellProps> = forwardRef(
    ({
        className,
        children,
        large,
        // @ts-ignore Layout is an internal prop to avoid code duplication for LayoutGrid
        layout,
        medium,
        small,
        tag: Tag = "div",
        ...props
    }, ref: Ref<HTMLElement>) => {
        const spanClasses: string[] = [];
        const layoutClass = layout ? "-layout" : "";

        if (small) {
            spanClasses.push(`axiom${layoutClass}-grid__cell--span-${small}-small`);
        }

        if (medium) {
            spanClasses.push(`axiom${layoutClass}-grid__cell--span-${medium}-medium`);
        }

        if (large) {
            spanClasses.push(`axiom${layoutClass}-grid__cell--span-${large}-large`);
        }

        return <Tag className={classNames(`axiom${layoutClass}-grid__cell`, spanClasses, className)} ref={ref} {...props}>{children}</Tag>;
    }
);
